@@ -14,11 +14,11 @@
 #include <tqstringlist.h>
 #include <tqlabel.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <ktoolbarbutton.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
+#include <tdetoolbarbutton.h>
 #include <kcombobox.h>
 #include <klineedit.h>
 #include <kuser.h>
@@ -31,7 +31,7 @@ OutputDirectory::OutputDirectory( Config* _config, TQWidget* parent, const char*
     config = _config;
 
     // create an icon loader object for loading icons
-    KIconLoader *iconLoader = new KIconLoader();
+    TDEIconLoader *iconLoader = new TDEIconLoader();
 
     TQGridLayout *grid = new TQGridLayout( this, 1, 1, 0, 3, "grid" );
 
@@ -53,13 +53,13 @@ OutputDirectory::OutputDirectory( Config* _config, TQWidget* parent, const char*
                this, TQT_SLOT(modeChangedSlot(int))
              );
     modeJustChanged = false;
-    /*pModeInfo = new KToolBarButton( "messagebox_info", 1010, this, "pModeInfo" );
+    /*pModeInfo = new TDEToolBarButton( "messagebox_info", 1010, this, "pModeInfo" );
     TQToolTip::add( pModeInfo, i18n("Information about the output mode") );
     box->addWidget( pModeInfo );
     connect( pModeInfo, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(modeInfo())
              );*/
-    pClear = new KToolBarButton( "locationbar_erase", 1001, this, "pClear" );
+    pClear = new TDEToolBarButton( "locationbar_erase", 1001, this, "pClear" );
     TQToolTip::add( pClear, i18n("Clear the directory input field") );
     box->addWidget( pClear );
     lDir = new KLineEdit( this, "lDir" );
@@ -73,19 +73,19 @@ OutputDirectory::OutputDirectory( Config* _config, TQWidget* parent, const char*
     connect( pClear, TQT_SIGNAL(clicked()),
                lDir, TQT_SLOT(clear())
              );
-    /*pDirInfo = new KToolBarButton( "messagebox_info", 1011, this, "pDirInfo" );
+    /*pDirInfo = new TDEToolBarButton( "messagebox_info", 1011, this, "pDirInfo" );
     TQToolTip::add( pDirInfo, i18n("Information about the wildcards") );
     box->addWidget( pDirInfo );
     connect( pDirInfo, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(dirInfo())
              );*/
-    pDirSelect = new KToolBarButton( "folder", 1012, this, "pDirSelect" );
+    pDirSelect = new TDEToolBarButton( "folder", 1012, this, "pDirSelect" );
     TQToolTip::add( pDirSelect, i18n("Choose an output directory") );
     box->addWidget( pDirSelect );
     connect( pDirSelect, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(selectDir())
              );
-    pDirGoto = new KToolBarButton( "konqueror", 1013, this, "pDirGoto" );
+    pDirGoto = new TDEToolBarButton( "konqueror", 1013, this, "pDirGoto" );
     TQToolTip::add( pDirGoto, i18n("Open Konqueror with the output directory") );
     box->addWidget( pDirGoto );
     connect( pDirGoto, TQT_SIGNAL(clicked()),
@@ -293,7 +293,7 @@ TQString OutputDirectory::uniqueFileName( const TQString& filename )
 
         for( KMountPoint::List::ConstIterator jt = mountPoints.begin(); jt != mountPoints.end(); ++jt )
         {
-            const KSharedPtr<KMountPoint> mp = *jt;
+            const TDESharedPtr<KMountPoint> mp = *jt;
             if( mp->mountedFrom() == device )
             {
                 filePathName = ( mp->mountPoint() == "/" ) ? mp->mountPoint() : mp->mountPoint() + "/";
@@ -419,7 +419,7 @@ void OutputDirectory::gotoDir()
     kfm << "kfmclient";
     kfm << "openURL";
     kfm << startDir;
-    kfm.start( KProcess::DontCare );
+    kfm.start( TDEProcess::DontCare );
 }
 
 void OutputDirectory::modeChangedSlot( int mode )
